/****************************************************************************
** Meta object code from reading C++ file 'externalcommandhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpmcore-26.04.1/src/util/externalcommandhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'externalcommandhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ExternalCommandHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto ExternalCommandHelper::qt_create_metaobjectdata<qt_meta_tag_ZN21ExternalCommandHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ExternalCommandHelper",
        "D-Bus Interface",
        "org.kde.kpmcore.externalcommand",
        "progress",
        "",
        "report",
        "RunCommand",
        "QVariantMap",
        "command",
        "arguments",
        "input",
        "processChannelMode",
        "CopyFileData",
        "sourceDevice",
        "sourceOffset",
        "sourceLength",
        "targetDevice",
        "targetOffset",
        "blockSize",
        "ReadData",
        "device",
        "offset",
        "length",
        "WriteData",
        "buffer",
        "WriteFstab",
        "fstabContents"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progress'
        QtMocHelpers::SignalData<void(int)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'report'
        QtMocHelpers::SignalData<void(QString)>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'RunCommand'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const QStringList &, const QByteArray &, const int)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7, {{
            { QMetaType::QString, 8 }, { QMetaType::QStringList, 9 }, { QMetaType::QByteArray, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'CopyFileData'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const qint64, const qint64, const QString &, const qint64, const qint64)>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7, {{
            { QMetaType::QString, 13 }, { QMetaType::LongLong, 14 }, { QMetaType::LongLong, 15 }, { QMetaType::QString, 16 },
            { QMetaType::LongLong, 17 }, { QMetaType::LongLong, 18 },
        }}),
        // Slot 'ReadData'
        QtMocHelpers::SlotData<QByteArray(const QString &, const qint64, const qint64)>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QByteArray, {{
            { QMetaType::QString, 20 }, { QMetaType::LongLong, 21 }, { QMetaType::LongLong, 22 },
        }}),
        // Slot 'WriteData'
        QtMocHelpers::SlotData<bool(const QByteArray &, const QString &, const qint64)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QByteArray, 24 }, { QMetaType::QString, 16 }, { QMetaType::LongLong, 17 },
        }}),
        // Slot 'WriteFstab'
        QtMocHelpers::SlotData<bool(const QByteArray &)>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QByteArray, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ExternalCommandHelper, qt_meta_tag_ZN21ExternalCommandHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ExternalCommandHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ExternalCommandHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ExternalCommandHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ExternalCommandHelperE_t>.metaTypes,
    nullptr
} };

void ExternalCommandHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExternalCommandHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->report((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { QVariantMap _r = _t->RunCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantMap _r = _t->CopyFileData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 4: { QByteArray _r = _t->ReadData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->WriteData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->WriteFstab((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ExternalCommandHelper::*)(int )>(_a, &ExternalCommandHelper::progress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalCommandHelper::*)(QString )>(_a, &ExternalCommandHelper::report, 1))
            return;
    }
}

const QMetaObject *ExternalCommandHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ExternalCommandHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ExternalCommandHelperE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int ExternalCommandHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ExternalCommandHelper::progress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ExternalCommandHelper::report(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
